# files with help

# help about nmcli
help_nmcli = """
A few helpful nmcli commands reminder:

    - nmcli dev status
    view the different interfaces and active connections

    - nmcli dev wifi list
    view the available WiFi points

    - nmcli radio wifi [on | off ]
    change the WiFi radio state
"""
